import sys 
import getpass
s = '/home/'+getpass.getuser()
#s = '/Users/'+getpass.getuser()
sys.path.insert(1, '%s/dptqm/Structural codes/Kerr resonator'%s)
sys.path.insert(1, '%s/dptqm/Structural codes/Dynamical Hilbert space'%s)
sys.path.insert(1, '%s/dptqm/Structural codes/Arnoldi-Linblad time evolution'%s)

from Arnoldi_Lindblad import AL
from Coupled_Kerr import *

def generateH(Ns,Nr, p1,p2,χ, fG=None, Gargs=None):
    k1 = Kerr(Ncut=Ns, p=p1, fG=fG, Gargs=Gargs)
    k2 = Kerr(Ncut=Nr, p=p2)
    cc = CoupleKerr(k1,k2,χ)
    e_ops = [cc.a.dag()*cc.a, cc.b.dag()*cc.b]
    return cc.H, cc.c_ops, e_ops, Gargs

if __name__ == "__main__":
    
    k1params = 7., 1.0, 0., 0., 0., 1.       #Δs, Us, Gs, Fs, γs, ηs
    k2params = 0., 0.3, 0., 4., 3., 0.       #Δr, Ur, Gr, Fr, γr, ηr
    k1params_nodpt = 0., 0.0, 0., 0., 0., 1. #Δs, Us, Gs, Fs, γs, ηs
    k2params_nodpt = 0., 0.3, 0., 4., 3., 0. #Δr, Ur, Gr, Fr, γr, ηr
    
    Ns,Nr,χ = 20,20,10
    
    p1 = Parameters(*k1params)
    p2 = Parameters(*k2params)
    p1_nodpt = Parameters(*k1params_nodpt)
    p2_nodpt = Parameters(*k2params_nodpt)
    
    generateL = lambda Ns, Nr : generateH(Ns, Nr, p1, p2, χ)
    generateL_nodpt = lambda Ns, Nr : generateH(Ns, Nr, p1_nodpt, p2_nodpt, χ)
    
    H, c_ops, _, _ = generateL(Ns,Nr)
    L = liouvillian_ref(H,c_ops)
    
    H_nodpt, c_ops_nodpt, _, _ = generateL_nodpt(Ns,Nr)
    L_nodpt = liouvillian_ref(H_nodpt, c_ops_nodpt)
    
    
    rho0 = tensor(rand_dm(Ns), rand_dm(Nr))
    _,_,_,_, eps = AL(L, rho0, n=200, T=3, nsteps=100, negvls=10, tau=1e-5,\
                                         eps=1e-12, check_first=10, check_every=10)
    
    rho0 = tensor(rand_dm(Ns), rand_dm(Nr))
    _,_,_,_, eps_nodpt = AL(L_nodpt, rho0, n=200, T=3, nsteps=100, negvls=10, tau=1e-5,\
                                         eps=1e-12, check_first=10, check_every=10)

    
    with open("G=0spectrum.pckl", "wb") as fp:
        pickle.dump([p1, p2, p1_nodpt, p2_nodpt, eps, eps_nodpt], fp)


